@@ -25,7 +25,6 @@
 
 #include <KStandardAction>
 #include <QAction>
-#include <KToggleAction>
 #include <KActionCollection>
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -37,13 +36,14 @@
 #include <QApplication>
 #include <QPointer>
 #include <QCloseEvent>
-#include <QActionGroup>
 #include <KSharedConfig>
 #include <QStandardPaths>
+#include <KAuthorized>
 
 ThemeEditorMainWindow::ThemeEditorMainWindow()
     : KXmlGuiWindow()
     , mThemeEditor(nullptr)
+    , mUploadTheme(nullptr)
 {
     setupActions();
     setupGUI();
@@ -79,7 +79,9 @@ void ThemeEditorMainWindow::updateActions()
     const bool projectDirectoryIsEmpty = (mThemeEditor != nullptr);
     mAddExtraPage->setEnabled(projectDirectoryIsEmpty);
     mCloseAction->setEnabled(projectDirectoryIsEmpty);
-    mUploadTheme->setEnabled(projectDirectoryIsEmpty);
+    if (mUploadTheme) {
+        mUploadTheme->setEnabled(projectDirectoryIsEmpty);
+    }
     mSaveAction->setEnabled(projectDirectoryIsEmpty);
     mInstallTheme->setEnabled(projectDirectoryIsEmpty);
     mInsertFile->setEnabled(projectDirectoryIsEmpty);
@@ -99,8 +101,9 @@ void ThemeEditorMainWindow::setupActions()
     mAddExtraPage = new QAction(i18n("Add Extra Page..."), this);
     connect(mAddExtraPage, &QAction::triggered, this, &ThemeEditorMainWindow::slotAddExtraPage);
     actionCollection()->addAction(QStringLiteral("add_extra_page"), mAddExtraPage);
-
-    mUploadTheme = KNS3::standardAction(i18n("Upload theme..."), this, SLOT(slotUploadTheme()), actionCollection(), "upload_theme");
+    if (KAuthorized::authorize(QStringLiteral("ghns"))) {
+        mUploadTheme = KNS3::standardAction(i18n("Upload theme..."), this, SLOT(slotUploadTheme()), actionCollection(), "upload_theme");
+    }
 
     mNewThemeAction = KStandardAction::openNew(this, &ThemeEditorMainWindow::slotNewTheme, actionCollection());
     mNewThemeAction->setText(i18n("New theme..."));
