@@ -34,8 +34,8 @@
 #include <QVBoxLayout>
 
 EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QString &projectDirectory, QWidget *parent)
-    : GrantleeThemeEditor::EditorPage(type, parent),
-      mWidgetSplitter(nullptr)
+    : GrantleeThemeEditor::EditorPage(type, parent)
+    , mWidgetSplitter(nullptr)
 {
     QVBoxLayout *lay = new QVBoxLayout(this);
     lay->setMargin(0);
@@ -73,7 +73,9 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 
     if (mType == MainPage) {
         KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
-        const QList<int> size{400, 100};
+        const QList<int> size {
+            400, 100
+        };
         mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
         mWidgetSplitter->setSizes(group.readEntry("widgetSplitter", size));
     }
@@ -92,4 +94,3 @@ GrantleeThemeEditor::PreviewWidget *EditorPage::preview() const
 {
     return mPreview;
 }
-
