@@ -28,9 +28,9 @@
 using namespace GrantleeThemeEditor;
 
 ThemeSession::ThemeSession(const QString &projectDirectory, const QString &themeTypeName)
-    : mProjectDirectory(projectDirectory),
-      mThemeTypeName(themeTypeName),
-      mVersion(1)
+    : mProjectDirectory(projectDirectory)
+    , mThemeTypeName(themeTypeName)
+    , mVersion(1)
 {
 }
 
